@@ -18,8 +18,7 @@ config = parser.add_argument('--config', '-c', default=os.getcwd(),
     help="Use the specified Markdoc config (a YAML file or a directory "
          "containing markdoc.yaml)")
 
-quiet = parser.add_argument('--quiet', '-q', default=False, action='store_true',
+quiet = parser.add_argument('--quiet', '-q', action='store_true',
     help="Suppress non-error output")
 
 subparsers = parser.add_subparsers(dest='command', title='commands', metavar='COMMAND')
-
